pub fn get_input_shred_from_num_vars(
num_vars: usize,
input_node: &InputLayerNode,
) -> InputShredExpand description
Using the number of variables, get an input shred that represents this information.
pub fn get_input_shred_from_num_vars(
num_vars: usize,
input_node: &InputLayerNode,
) -> InputShredUsing the number of variables, get an input shred that represents this information.